pub struct QueryTableHandle {
pub table: Box<dyn Table>,
pub in_explicit_transaction: bool,
/* private fields */
}Expand description
Owns the physical table handle and, for an implicit statement, the transaction whose snapshot keeps that handle valid.
Fields
table: Box<dyn Table>in_explicit_transaction: boolImplementations
Sourceimpl QueryTableHandle
impl QueryTableHandle
pub fn into_parts(self) -> (Box<dyn Table>, Option<Box<dyn Transaction>>, bool)