pub fn prepare_scan_predicate<'a>(
select_columns: &[Expression],
where_clause: Option<&'a Expression>,
all_columns: &[String],
schema: &Schema,
table_alias: Option<&str>,
context: &ExecutionContext,
functions: &FunctionRegistry,
where_has_subqueries: bool,
) -> PreparedPredicate<'a>Expand description
Resolve SELECT aliases, simplify constants, substitute correlated outer values and split the result into storage and residual predicates.