Module projection

Module projection 

Column dependency planning at the physical scan boundary.

Structs

NarrowKeyStreamPlan
A scan containing one join key and the table-local predicate dependencies.
ProjectionScanPlan
A scan that reads only predicate, ordering and output dependencies.

Functions

expression_projection
filtered_expression_projection
filtered_simple_projection
narrow_key_stream
ordered_distinct_projection
simple_projection_indices