clear_executor_thread_local_caches

Function clear_executor_thread_local_caches 

pub fn clear_executor_thread_local_caches()
Clear ALL thread-local caches to release memory. Call this when a database is dropped to prevent memory leaks. This also shrinks all cache capacities to zero where applicable.