pub fn clear_in_subquery_cache()Expand description
Clear the IN subquery cache completely.
NOTE: For normal operation, use invalidate_in_subquery_cache_for_table instead.
This is only used for explicit cache clearing (e.g., after DDL operations).
pub fn clear_in_subquery_cache()Clear the IN subquery cache completely.
NOTE: For normal operation, use invalidate_in_subquery_cache_for_table instead.
This is only used for explicit cache clearing (e.g., after DDL operations).