pub fn clear_semi_join_cache()Expand description
Clear the semi-join cache completely.
NOTE: This is now only used for explicit cache clearing (e.g., after DDL operations).
For DML operations, use invalidate_semi_join_cache_for_table instead.
pub fn clear_semi_join_cache()Clear the semi-join cache completely.
NOTE: This is now only used for explicit cache clearing (e.g., after DDL operations).
For DML operations, use invalidate_semi_join_cache_for_table instead.