pub struct TimeoutGuard { /* private fields */ }Expand description
Guard that automatically cancels a query after a timeout. Uses a global timeout manager for efficient handling of many concurrent timeouts.
Implementations
Sourceimpl TimeoutGuard
impl TimeoutGuard
Sourcepub fn new(ctx: &ExecutionContext) -> Option<Self>
pub fn new(ctx: &ExecutionContext) -> Option<Self>
Create a new timeout guard that will cancel the query after timeout_ms. Returns None if timeout_ms is 0 (no timeout).