Module credentials

Module credentials 

Shared password-verifier primitives for catalog and server authentication.

Constants

MAX_PASSWORD_BYTES

Functions

hash_password_verifier
Derive a salted Argon2id PHC verifier without retaining the plaintext.
validate_password_verifier
Validate that a configured verifier is a syntactically valid Argon2id PHC string.
verify_password_verifier
Verify a password without disclosing why a verifier did not match.