DDL Statement Execution
This module implements execution of Data Definition Language (DDL) statements:
- CREATE TABLE
- DROP TABLE
- CREATE INDEX
- DROP INDEX
- ALTER TABLE
- CREATE VIEW
- DROP VIEW
DDL Statement Execution
This module implements execution of Data Definition Language (DDL) statements: