pub fn bind_navigation_paths(
engine: &dyn Engine,
select: &SelectStatement,
) -> Result<Vec<NavigationExpr>>Expand description
Bind every navigation path in a SELECT without reading rows or choosing a physical execution strategy.
pub fn bind_navigation_paths(
engine: &dyn Engine,
select: &SelectStatement,
) -> Result<Vec<NavigationExpr>>Bind every navigation path in a SELECT without reading rows or choosing a physical execution strategy.