Module index_nested_loop

Module index_nested_loop 

Index Nested Loop Join Operator.

This operator implements index nested loop join with O(N * log M) complexity by using indexes on the inner table for lookups. It’s optimal when:

  • The inner (right) table has an index on the join key column
  • The outer (left) table is small or has good selectivity

For each row in the outer table, we use the index/PK to find matching rows in the inner table, avoiding a full scan of the inner table.

Structs

BatchIndexNestedLoopJoinOperator
Bounded batch Index-NL operator.
IndexNestedLoopJoinOperator
Index Nested Loop Join Operator.

Enums

IndexLookupStrategy
Index Nested Loop Join lookup strategy. Determines how to find matching rows in the inner (right) table.