pub struct MergeJoinOperator { /* private fields */ }Expand description
Merge Join Operator for pre-sorted inputs.
Both inputs must be sorted on their respective join keys. The operator performs a single pass through both inputs, producing matches as they’re found.
Implementations
Sourceimpl MergeJoinOperator
impl MergeJoinOperator
Sourcepub fn new(
left: Box<dyn Operator>,
right: Box<dyn Operator>,
join_type: JoinType,
left_key_indices: Vec<usize>,
right_key_indices: Vec<usize>,
) -> Self
pub fn new( left: Box<dyn Operator>, right: Box<dyn Operator>, join_type: JoinType, left_key_indices: Vec<usize>, right_key_indices: Vec<usize>, ) -> Self
Create a new merge join operator.
Arguments
left- Left input operator (must be sorted on left_key_indices)right- Right input operator (must be sorted on right_key_indices)join_type- Type of join (INNER, LEFT, RIGHT, FULL - NOT Cross)left_key_indices- Column indices for left join keysright_key_indices- Column indices for right join keys
Panics
Debug builds will panic if join_type is JoinType::Cross.
Cross joins should use NestedLoopJoinOperator instead.