pub fn extract_column_from_predicate(expr: &Expression) -> Option<String>Expand description
Extract the column name from a simple predicate (col = value)
pub fn extract_column_from_predicate(expr: &Expression) -> Option<String>Extract the column name from a simple predicate (col = value)