ExpressionSimplifier

Struct ExpressionSimplifier 

pub struct ExpressionSimplifier<'a> { /* private fields */ }
Expression simplifier that applies optimization rules

Implementations

Source

impl ExpressionSimplifier<'static>

pub fn new() -> Self

Create a new expression simplifier

Source

impl<'a> ExpressionSimplifier<'a>

pub fn with_registry(_function_registry: &'a FunctionRegistry) -> Self

Create a simplifier using the executor’s authoritative function registry.

pub fn was_simplified(&self) -> bool

Check if any simplifications were made in the last run

pub fn try_simplify(&mut self, expr: &Expression) -> Option<Expression>

Simplify an expression, applying all optimization rules. Returns Some(simplified) if changes were made, None if expression is unchanged. This avoids cloning expressions that can’t be simplified (like EXISTS subqueries).

pub fn simplify(&mut self, expr: &Expression) -> Expression

Simplify an expression, always returning an Expression. Use try_simplify() when you want to avoid cloning unchanged expressions.