ParallelConfig

Struct ParallelConfig 

pub struct ParallelConfig {
    pub enabled: bool,
    pub min_rows_for_parallel_filter: usize,
    pub min_rows_for_parallel_join: usize,
    pub chunk_size: usize,
    pub join_output_batch_rows: usize,
    pub join_output_batch_bytes: usize,
}
Configuration for parallel execution

Fields

enabled: bool

Whether parallel execution is enabled

min_rows_for_parallel_filter: usize

Minimum rows to trigger parallel scan + filter

min_rows_for_parallel_join: usize

Minimum build rows to trigger parallel hash join

chunk_size: usize

Chunk size for parallel processing (rows per thread task)

join_output_batch_rows: usize

Maximum probe rows retained by one parallel JOIN pull batch.

join_output_batch_bytes: usize

Maximum retained probe-row graph owned by one parallel JOIN pull batch.

Implementations

Source

impl ParallelConfig

pub fn should_parallel_filter(&self, row_count: usize) -> bool

Check if parallel filter should be used for the given row count

pub fn should_parallel_join(&self, build_rows: usize) -> bool

Check if parallel join should be used for the given build side row count