pub fn try_pushdown(
expr: &Expression,
schema: &Schema,
exec_ctx: Option<&ExecutionContext>,
) -> (Option<Box<dyn StorageExpr>>, bool)Expand description
Convenience function to try pushdown using the global registry
pub fn try_pushdown(
expr: &Expression,
schema: &Schema,
exec_ctx: Option<&ExecutionContext>,
) -> (Option<Box<dyn StorageExpr>>, bool)Convenience function to try pushdown using the global registry