pub struct PushdownRegistry { /* private fields */ }Expand description
Registry of all pushdown rules
The registry tries rules in order and returns the first successful conversion. Rules are ordered from most specific to most general.
Implementations
Sourceimpl PushdownRegistry
impl PushdownRegistry
Sourcepub fn register(&mut self, rule: Box<dyn PushdownRule>)
pub fn register(&mut self, rule: Box<dyn PushdownRule>)
Register a custom pushdown rule
Sourcepub fn try_pushdown(
&self,
expr: &Expression,
schema: &Schema,
exec_ctx: Option<&ExecutionContext>,
) -> (Option<Box<dyn StorageExpr>>, bool)
pub fn try_pushdown( &self, expr: &Expression, schema: &Schema, exec_ctx: Option<&ExecutionContext>, ) -> (Option<Box<dyn StorageExpr>>, bool)
Try to push down an expression to storage layer
Returns (Option<StorageExpr>, needs_memory_filter)