pub struct OrderedResult { /* private fields */ }Expand description
Ordered result that sorts rows by ORDER BY expressions
Implementations
Sourceimpl OrderedResult
impl OrderedResult
Sourcepub fn new<F>(inner: Box<dyn QueryResult>, compare: F) -> Result<Self>
pub fn new<F>(inner: Box<dyn QueryResult>, compare: F) -> Result<Self>
Create a new ordered result by materializing and sorting the inner result
Sourcepub fn new_radix<F>(
inner: Box<dyn QueryResult>,
order_specs: &[RadixOrderSpec],
fallback_compare: F,
) -> Result<Self>
pub fn new_radix<F>( inner: Box<dyn QueryResult>, order_specs: &[RadixOrderSpec], fallback_compare: F, ) -> Result<Self>
Create an ordered result using radix sort for integer columns
This is O(n) instead of O(n log n) for comparison-based sort. For 10K rows, this can be 2-5x faster. For 1M rows, 5-20x faster.
Arguments
inner- Source result to materialize and sortorder_specs- Column indices and sort directions (must be integer columns)fallback_compare- Fallback comparison function if radix sort fails