pub struct ProjectedResult { /* private fields */ }Expand description
Projected result that removes extra columns (e.g., ORDER BY columns not in SELECT)
This result type projects rows to only include the first N columns, removing any extra columns that were added for sorting purposes.
Implementations
Sourceimpl ProjectedResult
impl ProjectedResult
Sourcepub fn new(inner: Box<dyn QueryResult>, keep_columns: usize) -> Self
pub fn new(inner: Box<dyn QueryResult>, keep_columns: usize) -> Self
Create a new projected result