pub fn expression_contains_aggregate(expr: &Expression) -> boolExpand description
Check if an expression contains an aggregate function. Used for detecting nested aggregates and determining query structure.
pub fn expression_contains_aggregate(expr: &Expression) -> boolCheck if an expression contains an aggregate function. Used for detecting nested aggregates and determining query structure.