pub fn extract_column_name(expr: &Expression) -> Option<String>Expand description
Extract the column name from an Identifier or QualifiedIdentifier expression. Returns the column name without table qualifier.
pub fn extract_column_name(expr: &Expression) -> Option<String>Extract the column name from an Identifier or QualifiedIdentifier expression. Returns the column name without table qualifier.