pub fn get_table_alias_from_expr(expr: &Expression) -> Option<String>Expand description
Get table alias from a table expression. Returns the alias if specified, otherwise the table name.
pub fn get_table_alias_from_expr(expr: &Expression) -> Option<String>Get table alias from a table expression. Returns the alias if specified, otherwise the table name.