open_query_source

Function open_query_source 

pub fn open_query_source(
    engine: &Arc<MVCCEngine>,
    active_transaction: &Mutex<Option<ActiveTransaction>>,
    table_name: &str,
    temporal_requested: bool,
) -> Result<QuerySourceHandle>
Open the physical source once while preserving the legacy rule that an explicit transaction owns the snapshot and therefore suppresses AS OF.