pub type RowCounter = Box<dyn Fn(&[i64]) -> usize + Send + Sync>;Expand description
Type alias for row counter function used in COUNT(*) optimization. This only counts visible rows without cloning their data.
Aliased Type
pub struct RowCounter(/* private fields */);