pub struct ParallelConfig {
pub enabled: bool,
pub min_rows_for_parallel_filter: usize,
pub min_rows_for_parallel_join: usize,
pub chunk_size: usize,
pub join_output_batch_rows: usize,
pub join_output_batch_bytes: usize,
}Expand description
Configuration for parallel execution
Fields
enabled: boolWhether parallel execution is enabled
min_rows_for_parallel_filter: usizeMinimum rows to trigger parallel scan + filter
min_rows_for_parallel_join: usizeMinimum build rows to trigger parallel hash join
chunk_size: usizeChunk size for parallel processing (rows per thread task)
join_output_batch_rows: usizeMaximum probe rows retained by one parallel JOIN pull batch.
join_output_batch_bytes: usizeMaximum retained probe-row graph owned by one parallel JOIN pull batch.
Implementations
Sourceimpl ParallelConfig
impl ParallelConfig
Sourcepub fn should_parallel_filter(&self, row_count: usize) -> bool
pub fn should_parallel_filter(&self, row_count: usize) -> bool
Check if parallel filter should be used for the given row count
Sourcepub fn should_parallel_join(&self, build_rows: usize) -> bool
pub fn should_parallel_join(&self, build_rows: usize) -> bool
Check if parallel join should be used for the given build side row count