pub struct ExecutorResult { /* private fields */ }Implementations
Sourceimpl ExecutorResult
impl ExecutorResult
Sourcepub fn new(columns: Vec<String>, rows: RowVec) -> Self
pub fn new(columns: Vec<String>, rows: RowVec) -> Self
Create a new memory result with columns and pooled rows
Sourcepub fn with_arc_columns(columns: CompactArc<Vec<String>>, rows: RowVec) -> Self
pub fn with_arc_columns(columns: CompactArc<Vec<String>>, rows: RowVec) -> Self
Create a new memory result with Arc columns (zero-copy)
Create a new memory result with shared rows from cache (zero-copy for rows)
This avoids cloning the entire Vec<Row> when reading from semantic cache
Create a new memory result with Arc columns and shared rows (zero-copy for both)
Sourcepub fn with_columns(columns: Vec<String>) -> Self
pub fn with_columns(columns: Vec<String>) -> Self
Create with columns only (no rows yet)
Sourcepub fn into_arc_rows(self) -> CompactArc<Vec<Row>>
pub fn into_arc_rows(self) -> CompactArc<Vec<Row>>
Take rows as CompactArc for zero-copy sharing with joins
Returns CompactArc<Vec<Row>> - wraps owned rows or clones CompactArc for shared
Sourcepub fn set_rows_affected(&mut self, count: i64)
pub fn set_rows_affected(&mut self, count: i64)
Set rows affected (for modification results)
Sourcepub fn set_last_insert_id(&mut self, id: i64)
pub fn set_last_insert_id(&mut self, id: i64)
Set last insert ID