pub fn hash_row(row: &Row) -> u64Expand description
Hash all values in a row into a single hash value. Used for DISTINCT operations and set operations (UNION, INTERSECT, EXCEPT). Uses FxHasher which is optimized for trusted keys in embedded database context.